БЕЛОРУССКИЕ НОВОСТИ | Беларусь | Минск | мировые новости | последние новости | горячие новости
Description: мировые новости, последние новости, агентство новостей, горячие новости, Белорусская газета, Беларусь, Белоруссия, Белорусь, Беларусия, Беларуссия
Keywords: мировые новости, последние новости, агентство новостей, горячие новости, Белорусская газета, Беларусь, Белоруссия, Белорусь, Беларусия, Беларуссия

Рус Eng Mobile 04:16 | 10 декабря 2014 года | Среда
Регистрация Забыли пароль?

### Тема Интерактивная карта новостей

- Аудиослайдшоу. Беспилотники и бесхребетники
- Шпиономания. Мы все под колпаком КГБ?
- Москва может «за компанию» втянуть Минск в новое противостояние с НАТО
- Чем грозит Беларуси девальвация российского рубля. Прогнозов много, ясности никакой

- Скоро на сайте
  - Армия белорусских «тунеядцев» может получить подкрепление из России
  - Аудиослайдшоу: хроника минувшей недели в картинках
- Подсказать тему
- Все темы
- Все статьи

- 09.12/19:52 Финансы Комментарии: 1

  ## Бюджет-2015: где власти найдут деньги и куда они пойдут?

  Проект бюджета на 2015 год находится на рассмотрении в белорусском парламенте...

- 09.12/13:54 Общество

  ## В Беларуси открывается корпункт рупора Кремля

  Корпункт «России сегодня» будет представлять из себя мультимедийный хаб, в котором будет работать более 20 человек...

- 09.12/13:43 Авто Комментарии: 1

  ## За хобби пинчанина, обменявшего машину 27 раз, налоговая требует $220 тысяч

  Бросив курить, Сергей Чижик приобрел другую страсть — он увлекся обменом автомобилей. Необычное хобби налоговая оценила в $220 тысяч как незаконное предпринимательство…

- 09.12/08:56 Экономика Комментарии: 9

  ## Форум предпринимателей: «Нас десятки тысяч, можем миллион подписей собрать»

  Представители малого бизнеса просят Лукашенко наложить мораторий на проведение проверок и практику конфискации товаров...

- 08.12/20:15 Общество Комментарии: 4

  ## Дело Мальцева. Новое обвинение — гендиректор «Борисовдрева» теперь не «паразит»

  Теперь ожидается новый допрос Владимира Мальцева по пунктам нового обвинения, которое существенно напоминает старое…

- 08.12/18:44 Общество

  ## Страховая медицина в Беларуси. Стоит ли торопить процесс?

  «Люди говорят, что готовы к введению страховой медицины, потому что устали от обилия платных услуг в государственных учреждениях здравоохранения…»

- 08.12/14:15 Общество

  ## Алименты из прошлого. Белорус задолжал гражданской жене миллион российских рублей

  История началась еще во времена распада СССР, когда из Таджикистана, спасаясь от разного рода проблем, в Витебскую область приехала...

- 08.12/13:51 Общество Комментарии: 15

  ## Что думают белорусы: отношение общества к смертной казни

  Дискуссия на эту тему состоится 10 декабря…

- 08.12/10:47 Заграница Комментарии: 2

  ## Опыт соседей. Белорусы — за Семашко, а молдаване — за Бисмарка

  Даже в не самой богатой стране можно проводить успешные социальные реформы, если на то есть политическая воля государства и общества...

- 07.12/23:19 Общество

  ## Ухо недели. Дохлые проблемы

  Большинство трудностей, возникающих в отношениях Беларуси и России, не стоят и выеденного яйца. И решаются они на раз — телефонным звонком...

- 07.12/17:43 Общество Комментарии: 8

  ## «Беларусь без крайностей». Есть ли жизнь после президентских выборов?

  Эксперты «Либерального клуба» анализируют главные события в белорусской политике, экономике, праве, социологии и культуре...

- 07.12/15:06 Политика Комментарии: 1

  ## Превентивные задержания опять войдут в моду в политическом сезоне-2015

  Перед президентскими выборами давление на активную часть гражданского общества вновь усилится…